@@ -252,7 +252,7 @@ class Fetcher(object):
 				# Primary failed
 				primary = None
 				primary_ex = ex
-				logger.warn(_("Feed download from %(url)s failed: %(exception)s"), {'url': feed_url, 'exception': ex})
+				logger.warning(_("Feed download from %(url)s failed: %(exception)s"), {'url': feed_url, 'exception': ex})
 
 			# Start downloading from mirror...
 			mirror = self._download_and_import_feed(feed_url, use_mirror = True)
@@ -430,6 +430,11 @@ class Fetcher(object):
 									None, None, type = 'application/x-bzip-compressed-tar')
 						continue		# Retry
 					raise
+				except SafeException as ex:
+					raise SafeException("Error fetching {url} {version}: {ex}".format(
+						url = impl.feed.url,
+						version = impl.get_version(),
+						ex = ex))
 				break
 
 			self.handler.impl_added_to_store(impl)
@@ -526,7 +531,7 @@ class Fetcher(object):
 			source = icon.getAttribute('href')
 			if source:
 				break
-			logger.warn(_('Missing "href" attribute on <icon> in %s'), interface)
+			logger.warning(_('Missing "href" attribute on <icon> in %s'), interface)
 		else:
 			logger.info(_('No PNG icons found in %s'), interface)
 			return
