@@ -187,7 +187,7 @@ def process_depends(item, local_feed_dir):
 			r = VersionExpressionRestriction(version)
 		except SafeException as ex:
 			msg = "Can't parse version restriction '{version}': {error}".format(version = version, error = ex)
-			logger.warn(msg)
+			logger.warning(msg)
 			r = ImpossibleRestriction(msg)
 		dependency.restrictions.append(r)
 
@@ -286,7 +286,7 @@ class VersionRangeRestriction(Restriction):
 
 class VersionExpressionRestriction(Restriction):
 	"""Only versions for which the expression is true are acceptable.
-	@since 1.13"""
+	@since: 1.13"""
 	__slots__ = ['expr', '_test_fn']
 
 	def __init__(self, expr):
@@ -331,7 +331,7 @@ class DistributionRestriction(Restriction):
 		return impl.distro_name in self.distros
 
 	def __str__(self):
-		return "distro " + '|'.join(self.distros)
+		return "distro " + '|'.join(sorted(self.distros))
 
 class Binding(object):
 	"""Information about how the choice of a Dependency is made known
@@ -1174,7 +1174,7 @@ class ZeroInstallFeed(object):
 					# In older feeds, the ID was the (single) digest
 					impl.digests.append(id)
 			if id in self.implementations:
-				logger.warn(_("Duplicate ID '%(id)s' in feed '%(feed)s'"), {'id': id, 'feed': self})
+				logger.warning(_("Duplicate ID '%(id)s' in feed '%(feed)s'"), {'id': id, 'feed': self})
 			self.implementations[id] = impl
 
 			impl.metadata = item_attrs
